United States Patent: 6095661

| ( 1 of 1 )

United States Patent | 6,095,661
Lebens , et al. | August 1, 2000

**Please see images for: ( PTAB Trial Certificate ) **

Method and apparatus for an L.E.D. flashlight
Abstract

Improved method and apparatus for hand-held portable illumination. A flashlight and corresponding method are described. The flashlight includes a housing, a plurality of LEDs, and an electrical circuit that selectively applies power from the DC voltage source to the LED units, wherein the flashlight is suitable for handheld portable operation by a user. In one embodiment, the first electrical circuit further includes a control circuit for maintaining a predetermined light output level of the LED units as a charge on a battery varies. In another embodiment, the control circuit maintains an average predetermined light output level of the LED units as the charge on the battery cell varies by changing a pulse width or frequency as the charge on the battery cell varies to maintain a given average light output. Another aspect provides an illumination source that includes a light-emitting diode (LED) housing including one or more LEDs, and a control circuit that selectively applies power from a source of electric power to the LEDs, the control circuit substantially maintaining a light output characteristic of the LEDs as a voltage of the voltage source varies over a range that would otherwise vary the light output characteristic. Still another aspect provides an illumination source including a light-emitting diode (LED) housing including one or more LEDs; and a control circuit that selectively applies power from a source of electric power to the LEDs, thus maintaining or controlling a light output color spectrum of the LEDs.

Inventors: | Lebens; Gary A. (Chaska, MN), Bourn; Charles T. (Minnetonka, MN), Lemaire; Charles A. (Apple Valley, MN)
Assignee: | PPT Vision, Inc. (Eden Prairie, MN)
Family ID: | 21933046
Appl. No.: | 09/044,559
Filed: | March 19, 1998

Current U.S. Class: | 362/184; 315/224; 315/307; 362/183; 362/157; 315/360; 362/800; 362/159; 315/291; 315/312; 315/362; 362/208; 348/E5.038; 362/249.05; 362/249.06
Current CPC Class: | H04B 10/564 (20130101); H05B 45/395 (20200101); F21L 4/027 (20130101); H05B 45/50 (20200101); H04B 10/502 (20130101); H04N 5/2354 (20130101); H05B 45/12 (20200101); H05B 45/22 (20200101); H05B 45/20 (20200101); Y02B 20/30 (20130101); H05B 45/32 (20200101); Y10S 362/80 (20130101); Y10S 362/802 (20130101); F21Y 2115/10 (20160801)
Current International Class: | F21L 4/02 (20060101); F21L 4/00 (20060101); H04N 5/235 (20060101); H04B 10/155 (20060101); H04B 10/152 (20060101); H04B 010/04 ()
Field of Search: | ;362/157,183,159,184,208,800,249 ;315/224,307,291,312,360,362

References Cited [Referenced By]

U.S. Patent Documents

4208579 | June 1980 | Scrivo
4290095 | September 1981 | Schmidt
4346329 | August 1982 | Schmidt
4509266 | April 1985 | Cusack
4592147 | June 1986 | Herman
4820229 | April 1989 | Spraggins
4831504 | May 1989 | Nishizawa et al.
4893815 | January 1990 | Rowan
4962347 | October 1990 | Burroughs et al.
4964023 | October 1990 | Nishizawa et al.
4978857 | December 1990 | Juengel
5015918 | May 1991 | Copeland
5065035 | November 1991 | Juengel
5179335 | January 1993 | Nor
5279513 | January 1994 | Connelly
5299227 | March 1994 | Rose
5424927 | June 1995 | Schaller et al.
5838247 | November 1998 | Bladowski
5890794 | April 1999 | Abtahi et al.

Primary Examiner: O'Shea; Sandra
Assistant Examiner: Zeade; Bertrand
Attorney, Agent or Firm: Schwegman, Lundberg, Woessner & Kluth, P.A.

Claims

What is claimed is:
1. A flashlight, comprising:
(a) a flashlight housing, the housing being suitable for at least one of receiving therein and mounting thereon at least one DC voltage source;
(b) a light-emitting diode (LED) housing connected to the flashlight housing, the LED housing comprising a first plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an optical axis of one of the plurality of LED units, the first plurality of LED units including at least seven individual LED units; and
(c) a first electrical circuit that selectively applies pulsed power from the DC voltage source to the LED units, wherein the pulses have a frequency high enough that light produced by the LED units has an appearance to a human user of being continuous rather than pulsed, and the pulses have at least one characteristic that is controlled by the first electrical circuit in order to maintain an average predetermined light output level of the LED units as a voltage on the DC voltage source varies;
wherein the flashlight is of such compact size and low weight as to be suitable for single-handed portable operation by a user, the flashlight further having a purpose of providing general-purpose illumination.
2. The flashlight of claim 1, wherein the LED optical axes of the first plurality of LED units are substantially parallel to one another.
3. The flashlight of claim 2, further comprising:
a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein the LED optical axes of the second plurality of LED units converge forwardly from the housing.
4. The flashlight of claim 1, wherein an optical spread angle of the first plurality of LED units are substantially equal to one another.
5. The flashlight of claim 4, further comprising:
a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein an optical spread angle of the second plurality of LED units are substantially equal to one another, and different than the optical spread angle of the first plurality of LED units.
6. The flashlight of claim 1, wherein the DC voltage source includes at least one battery cell.
7. The flashlight of claim 6, wherein
the LED units are connected in a parallel-series configuration with at least two LED units coupled in parallel to one another and in series with at least one other LED unit; and
the DC voltage source includes at least three battery cells connected in series.
8. The flashlight of claim 6, wherein the first electrical circuit further includes a control circuit for maintaining a predetermined light output level of the LED units as a charge on the battery cell varies.
9. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units as the charge on the battery cell varies by increasing a pulse width to the LED units as the charge on the battery cell decreases.
10. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring a battery voltage and adjusting a pulse width to the LED units based on the measured voltage to maintain the average light output at the predetermined level.
11. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring an average light output and adjusting a pulse width to the LED units based o n the measured light output to maintain the measured average light output at the predetermined level.
12. A flashlight, comprising:
(a) a flashlight housing, the housing being suitable for at least one of receiving therein and mounting thereon at least one DC voltage source that includes at least one battery cell;
(b) a light-emitting diode (LED) housing connected to the flashlight housing, the LED housing comprising one or more first LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis; and
(c) a first electrical circuit that selectively applies power from the DC voltage source to the LED units, the first electrical circuit further comprising a control circuit for maintaining a predetermined light output level of the LED units as a charge on the battery cell varies;
wherein the flashlight is of such compact size and low weight as to be suitable for single-handed portable operation by a user, the flashlight further having a purpose of providing general-purpose illumination.
13. The flashlight of claim 12, the first LED units being a first plurality of LED units, wherein the LED optical axes of the first plurality of LED units are substantially parallel to one another.
14. The flashlight of claim 13, further comprising:
a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein the LED optical axes of the second plurality of LED units converge from one another forwardly from the housing.
15. The flashlight of claim 12, the first LED units being a first plurality of LED units, wherein an optical spread angle of the first plurality of LED units are substantially equal to one another.
16. The flashlight of claim 15, further comprising:
a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein an optical spread angle of the second plurality of LED units are substantially equal to one another, and different than the optical spread angle of the first plurality of LED units.
17. A method of providing general-purpose illumination of such compact size and low weight as to be suitable for single-handed portable operation by a user, comprising the steps of:
(a) providing one or more first LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis;
(b) selectively applying power from a DC voltage source to the LED units; and
(c) maintaining a predetermined light output level of the LED units as a charge on the DC voltage source varies by controlling the step (b).
18. The method of claim 17, wherein the step of maintaining maintains an average predetermined light output level of the LED units as the charge on the battery cell varies by increasing one or more pulse characteristics selected from the group consisting of
(1) a pulse width,
(2) a pulse energy, and
(3) a pulse frequency
as the charge on the battery cell decreases.
19. The method of claim 17, wherein the step of maintaining maintains an average predetermined light output level of the LED units by measuring a battery voltage and adjusting
one or more pulse characteristics selected from the group consisting of
(1) a pulse width,
(2) a pulse energy, and
(3) a pulse frequency to the LED units based on the measured voltage to maintain the average light output at the predetermined level.
20. The method of claim 17, wherein the step of maintaining maintains an average predetermined light output level of the LED units by measuring a light output and adjusting one or more pulse characteristics selected from the group consisting of
(1) a pulse width,
(2) a pulse energy, and
(3) a pulse frequency to the LED units based on the measured light output to maintain an average light output at the predetermined level.
21. An illumination source, comprising:
(a) a light-emitting diode (LED) housing comprising one or more LEDs; and
(b) a control circuit that selectively applies power from a source of electric power to the LEDs, the control circuit substantially maintaining a light output characteristic of the LEDs as a voltage of the voltage source varies over a range that would otherwise vary the light output characteristic.
22. The illumination source of claim 21, wherein the light output characteristic that is maintained is light output intensity.
23. The illumination source of claim 22, wherein the control circuit maintains the light output intensity of the LED units as the voltage of the DC voltage source varies by increasing
one or more pulse characteristics selected from the group consisting of
(1) a pulse width,
(2) a pulse energy, and
(3) a pulse frequency
as the voltage of the DC voltage source decreases.
24. The illumination source of claim 22, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring a voltage and adjusting
one or more pulse characteristics selected from the group consisting of
(1) a pulse width,
(2) a pulse energy, and
(3) a pulse frequency
to maintain the average light output at the predetermined level.
25. The illumination source of claim 22, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring an average light output and adjusting a pulse width or a pulse frequency or both to maintain the measured average light output at the predetermined level.
26. A battery-powered portable flashlight (100) comprising:
a casing (110) suitable to hold a battery;
one or more light-emitting devices (LEDs) (150) mounted to the casing;
a switch (140) mounted to the casing; and
a control circuit (130) coupled to the battery, the LEDs, and the switch, wherein the control circuit drives the LEDs with electrical pulses at a frequency high enough that light produced by the LEDs has an appearance to a human user of being continuous rather than pulsed, and wherein the LEDs have proportion of on-time that increases as remaining battery power decreases.
27. The flashlight of claim 26, further comprising:
a feedback circuit that controls the pulses so that light intensity produced by the LEDs, as perceived by the human user, is substantially constant across a greater range of battery power than a corresponding range for which light intensity is equally constant without the feedback circuit.
28. The flashlight of claim 27, wherein the feedback circuit measures a light output of the LEDs.
29. The flashlight of claim 26, further comprising:
a battery-voltage-measuring circuit coupled to the control circuit.
30. A method for driving battery-powered portable flashlight (100) having a casing (110), a DC power source mounted to the casing, one or more solid-state light-emitting device (LEDs) (150) mounted to the casing, the method comprising the steps of:
receiving input from a user; and
based on the received input, generating a series of pulses to drive the LEDs such that the LEDs have proportion of on-time that increases as remaining battery power decreases.
31. An illumination source, comprising:
(a) a light-emitting diode (LED) housing comprising one or more LEDs;
(b) a source of electrical power; and
(c) a control circuit that selectively applies power from a source of electric power to the one or more LEDs to substantially maintain a predetermined color spectrum of the one or more LEDs as a voltage of the source of electric power varies over a range that would otherwise vary the light output color spectrum.
32. The illumination source of claim 31, wherein:
the one or more LEDs comprise one or more LEDs having a first characteristic color spectrum output and one or more LEDs having a second characteristic color spectrum output, the first characteristic color spectrum output different from the second characteristic color spectrum output; and wherein
the control circuit controls a pulse characteristic in order to control the proportion of light output having the first characteristic color spectrum output to that having the second characteristic color spectrum output.
33. The illumination source of claim 31, wherein:
the one or more LEDs comprise one or more LEDs each one having a characteristic color spectrum output that varies based on applied current; and wherein
the control circuit controls a pulse current in order to control the characteristic color spectrum output.
34. An illumination source, comprising:
(a) a light-emitting diode (LED) housing comprising one or more LEDs; and
(b) an electrical control circuit that selectively applies pulsed power from a DC voltage source of electric power to the LEDs to control a light output color spectrum of the one or more LEDs and maintain a predetermined light output level of the LED units as a charge on the DC voltage source varies.
35. The illumination source of claim 34, wherein:
the one or more LEDs comprise one or more LEDs having a first characteristic color spectrum output and one or more LEDs having a second characteristic color spectrum output, the first characteristic color spectrum output different from the second characteristic color spectrum output; and wherein
the control circuit controls one or more pulse characteristics in order to control the proportion of light output having the first characteristic color spectrum output to that having the second characteristic color spectrum output.
36. The Illumination source of claim 34, wherein:
the one or more LEDs comprise one or more LEDs each having a characteristic color spectrum output that varies based on applied current; and wherein
the control circuit controls a pulse current in order to control the characteristic color spectrum output.
37. The illumination source of claim 34, further comprising:
(c) a machine-vision imaging device; and
(d) an image processor coupled to receive image signals from the imaging device, wherein the control circuit controls.
38. The flashlight of claim 26, further comprising:
a feedback circuit that controls the pulses so that light intensity produced by the LEDs, as perceived by the human user, is substantially constant across a greater range of battery voltage than a corresponding range for which light intensity is equally constant without the feedback circuit.
39. The flashlight of claim 2, further comprising:
a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein the LED optical axes of the second plurality of LED units diverge from one another forwardly from the housing.
40. The flashlight of claim 1, wherein the first electrical circuit further includes a control circuit for maintaining a predetermined light output level of the LED units as a voltage on the DC voltage source varies.
41. The flashlight of claim 40, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring a voltage and adjusting a pulse width to the LED units to maintain the average light output at the predetermined level.
42. The flashlight of claim 40, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring a voltage and adjusting a pulse energy to the LED units to maintain the average light output at the predetermined level.
43. The flashlight of claim 40, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring a voltage and adjusting a pulse frequency to the LED units to maintain the average light output at the predetermined level.
44. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units as the charge on the battery cell varies by increasing a pulse frequency as the charge on the battery cell decreases.
45. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units as the charge on the battery cell varies by increasing a pulse energy as the charge on the battery cell decreases.
46. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring a battery voltage and adjusting a pulse frequency based on the measured voltage to maintain the average light output at the predetermined level.
47. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring a battery voltage and adjusting a pulse energy based on the measured voltage to maintain the average light output at the predetermined level.
48. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring an average light output and adjusting a pulse frequency based on the measured light output to maintain the measured average light output at the predetermined level.
49. The flashlight of claim 8, wherein the control circuit maintains an average predetermined light output level of the LED units by measuring an average light output and adjusting a pulse energy based on the measured light output to maintain the measured average light output at the predetermined level.
50. The flashlight of claim 13, further comprising:
a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein the LED optical axes of the second plurality of LED units diverge from one another forwardly from the housing.
51. The illumination source of claim 34, wherein:
the control circuit further controls a pulse width in order to further control an average light intensity.
52. The illumination source of claim 34, wherein:
the control circuit further controls a pulse frequency in order to further control an average light intensity.

Description

FIELD OF THE INVENTION
This invention relates to the field of lighting, and more specifically to a method and apparatus of controlling and powering a solid-state light source such as a light-emitting diode or LED, for a portable battery-powered flashlight.
BACKGROUND OF THE INVENTION
There is a widespread need for hand-held flashlights and lanterns. One common flashlight includes a two-cell battery for power, an incandescent lamp to emit light, and a simple single-pole switch to connect and disconnect the battery to the lamp. Other flashlights use other numbers of battery cells in order to provide a voltage suitable for various particular conditions. Lanterns often use a fluorescent tube to emit light. Certain keychain fobs use a pair of hearing-aid cells and a red-light light-emitting diode (LED) in order to provide short-range lighting such as might be -needed to find a keyhole in the dark.
Battery technology is such that as electrical power is withdrawn from a battery cell, the voltage available across a given current load will decrease. This decreased available voltage across the given load causes reduced light output, gradually dimming the light as the battery charge depletes.
Further, LEDs have voltage, current, and power parameters that must be controlled in order to maximize device life. Commonly, a current-limiting resistor is placed in series with an LED in order that only a portion of the voltage drop from the battery is across the LED and the rest of the voltage drop is across the resistor. This voltage drop and corresponding power loss in the resistor is dissipated as waste heat, which is inefficient for a flashlight which should be designed to emit light.
In addition, it is awkward or difficult to determine the amount of remaining charge in a battery cell, generally requiring removal of the battery from the flashlight in order to measure the remaining charge. In addition, the cost of a separate measurement device can be a negative for this market. Some battery cells today include a built-in liquid-crystal indicator for the charge in the cell, but such a solution requires a separate measurement device/indicator for each battery, and requires removal of the battery from the flashlight in order to perform the measurement and observe the indication of remaining power.
SUMMARY OF THE INVENTION
The present invention provides a method and apparatus for an L.E.D. flashlight or other LED illumination source. In one embodiment, a flashlight is described. The flashlight includes a flashlight housing suitable for receiving therein and/or mounting thereon at least one DC voltage source such as a battery. The flashlight also includes a light-emitting diode (LED) housing connected to the flashlight housing, the LED housing including a first plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, the first plurality of LED units including at least seven individual LED units. The flashlight also includes a first electrical circuit that selectively applies power from the DC voltage source to the LED units, wherein the flashlight is of such compact size and low weight as to be suitable for single-handed portable operation by a user, the flashlight further having a purpose of providing general-purpose illumination.
In one embodiment, the LED optical axes of the first plurality of LED units in the flashlight are substantially parallel to one another. In one such embodiment, the flashlight further includes a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein the LED optical axes of the second plurality of LED units converge or diverge from one another forwardly from the housing.
In another embodiment, an optical spread angle of the first plurality of LED units in the flashlight are substantially equal to one another. In one such embodiment, the flashlight further includes a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein an optical spread angle of the second plurality of LED units are substantially equal to one another, and different than the optical spread angle of the first plurality of LED units.
In yet another embodiment, the LED units are connected in a parallel-series configuration with at least two LED units coupled in parallel to one another and in series with at least one other LED unit, and the DC voltage source includes at least three battery cells connected in series.
In still another embodiment, the first electrical circuit further includes a control circuit for maintaining a predetermined light output level of the LED units as a charge on the battery cell varies. In one such embodiment, the control circuit maintains an average predetermined light output level of the LED units as the charge on the battery cell varies by increasing a pulse width or a pulse frequency as the charge on the battery cell decreases. In another such embodiment, the control circuit maintains an average predetermined light output level of the LED units by measuring a battery voltage and adjusting a pulse width or a pulse frequency or both to maintain the average light output at the predetermined level. In still another such embodiment, the control circuit maintains an average predetermined light output level of the LED units by measuring an average light output and adjusting a pulse width or a pulse frequency or both to maintain the measured average light output at the predetermined level.
Another aspect of the present invention provides a flashlight including: (a) a flashlight housing, the housing being suitable for at least one of receiving therein and mounting thereon at least one DC voltage source that includes at least one battery cell; (b) a light-emitting diode (LED) housing connected to the flashlight housing, the LED housing including one or more first LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis; and (c) a first electrical circuit that selectively applies power from the DC voltage source to the LED units, the first electrical circuit further including a control circuit for maintaining a predetermined light output level of the LED units as a charge on the battery cell varies; wherein the flashlight is of such compact size and low weight as to be suitable for single-handed portable operation by a user, the flashlight further having a purpose of providing general-purpose illumination.
In one such embodiment, the first LED units being a first plurality of LED units, wherein the LED optical axes of the first plurality of LED units are substantially parallel to one another. In another such embodiment, the flashlight further includes a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein the LED optical axes of the second plurality of LED units converge or diverge from one another forwardly from the housing.
In another such embodiment, the first LED units are a first plurality of LED units, wherein an optical spread angle of the first plurality of LED units are substantially equal to one another. In yet another such embodiment, the flashlight further includes a second plurality of LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis, wherein an optical spread angle of the second plurality of LED units are substantially equal to one another, and different than the optical spread angle of the first plurality of LED units.
Another aspect of the present invention provides a method of providing general-purpose illumination of such compact size and low weight as to be suitable for single-handed portable operation by a user, including the steps of: (a) providing one or more first LED units that each emit light and have a reflector for collimating the emitted light forwardly therefrom generally along an LED optical axis; (b) selectively applying power from a DC voltage source to the LED units; and (c) maintaining a predetermined light output level of the LED units as a charge on the battery cell varies by controlling the step (b).
In one embodiment, the step of maintaining maintains an average predetermined light output level of the LED units as the charge on the battery cell, varies by increasing a pulse energy or a pulse frequency as the charge on the battery cell decreases. In another embodiment, the step of maintaining maintains an average predetermined light output level of the LED units by measuring a battery voltage and adjusting a pulse width or a pulse frequency or both to maintain the average light output at the predetermined level. In still another embodiment, the step of maintaining maintains an average predetermined light output level of the LED units by measuring a light output and adjusting a pulse energy or a pulse frequency or both to maintain an average light output at the predetermined level.
Yet another aspect of the present invention provides an illumination source, that includes (a) a light-emitting diode (LED) housing including one or more LEDs; and (b) a control circuit that selectively applies power from a source of electric power to the LEDs, the control circuit substantially maintaining a light output characteristic of the LEDs as a voltage of the voltage source varies over a range that would otherwise vary the light output characteristic. In one such embodiment, the light output characteristic that is maintained is light output intensity. In another such embodiment, the control circuit maintains the light output intensity of the LED units as the voltage of the DC voltage source varies by increasing a pulse width, a pulse energy, or a pulse frequency as the voltage of the DC voltage source decreases. In another such embodiment, the control circuit maintains an average predetermined light output level of the LED units by measuring a voltage and adjusting a pulse energy or a pulse frequency or both to maintain the average light output at the predetermined level. In yet another such embodiment, the control circuit maintains an average predetermined light output level of the LED units by measuring an average light output and adjusting a pulse width or a pulse frequency or both to maintain the measured average light output at the predetermined level.
Another aspect of the present invention provides a battery-powered portable flashlight (100) including: a casing (110) suitable to hold a battery; one or more light-emitting devices (LEDs) (150) mounted to the casing; a switch (140) mounted to the casing; and a control circuit (130) coupled to the battery, the LEDs, and the switch, wherein the control circuit drives the LEDs with electrical pulses at a frequency high enough that light produced by the LEDs has an appearance to a human user of being continuous rather than pulsed, and wherein the LEDs have proportion of on-time that increases as remaining battery power decreases. One such embodiment further includes a feedback circuit that controls the pulses so that light intensity produced by the LEDs, as perceived by the human user, is substantially constant across a greater range of battery power or voltage than a corresponding range for which light intensity is equally constant without the feedback circuit. In one such embodiment, the feedback circuit measures a light output of the LEDs. Another such embodiment further includes a battery-voltage-measuring circuit coupled to the control circuit.
Yet another aspect of the present invention provides a method for driving battery-powered portable flashlight (100) having a casing (110), a DC power source mounted to the casing, one or more solid-state light-emitting device (LEDs) (150) mounted to the casing, the method including the steps of: receiving input from a user; and based on the received input, generating a series of pulses to drive the LEDs such that the LEDs have proportion of on-time that increases as remaining battery power decreases.
Still another aspect of the present invention provides an illumination source including (a) a light-emitting diode (LED) housing including one or more LEDs; and (b) a control circuit that selectively applies power from a source of electric power to the one or more LEDs, the control circuit maintaining a predetermined light output color spectrum of the one or more LEDs as a voltage of the source of electric power varies. In one such embodiment, the one or more LEDs comprise one or more LEDs having a first characteristic color spectrum output and one or more LEDs having a second characteristic color spectrum output, the first characteristic color spectrum output different from the second characteristic color spectrum output, and the control circuit controls a pulse characteristic in order to control the proportion of light output having the first characteristic color spectrum output to that having the second characteristic color spectrum output. In another such embodiment, the one or more LEDs comprise one or more LEDs having a characteristic color spectrum output that varies based on applied current, and the control circuit controls a pulse current in order to control the characteristic color spectrum output.
Yet another aspect of the present invention provides an illumination source that includes (a) a light-emitting diode (LED) housing including one or more LEDs; and (b) a control circuit that selectively applies power from a source of electric power to the LEDs to adjust a light output color spectrum of the one or more LEDs.
BRIEF DESCRIPTION OF THE DRAWINGS
FIG. 1 shows one embodiment of the present invention, a schematic representation of a handheld LED flashlight 100.
FIG. 2 is a circuit block diagram of an LED flashlight circuit 200, which circuit is used in some embodiments of LED flashlight 100 of FIG. 1 or LED light source in camcorder 500 of FIG. 5 or other devices such as machine-vision systems.
FIG. 3 a circuit block diagram of an LED flashlight circuit 300, which circuit is used in some embodiments of LED flashlight 100 of FIG. 1 or LED light source in camcorder 500 of FIG. 5 or other devices such as machine-vision systems.
FIG. 4 a circuit block diagram of an LED flashlight circuit 400, which circuit is used in some embodiments of LED flashlight 100 of FIG. 1 or LED light source in camcorder 500 of FIG. 5 or other devices such as machine-vision systems.
FIG. 5 is a diagram showing a controlled LED light source is integrated
into a handheld camcorder 500.
FIG. 6 is a graph of color spectrum versus current for an LED to be used in one embodiment of the present invention
FIG. 7 is circuit block diagram of an LED illumination device circuit 700, which circuit is used in some embodiments of LED flashlight 100 of FIG. 1 or LED light source in camcorder 500 of FIG. 5 or other devices such as machine-vision systems.
FIG. 8 is circuit block diagram of an LED illumination device circuit 700 that uses a current mirror.
FIG. 9 is a graph of color spectrum (photoluminescence) versus temperature for an LED to be used in one embodiment of the present invention.
FIG. 10 is circuit block diagram of a machine vision system using an LED illumination device according to the present invention.
FIG. 11 is circuit block diagram of an LED illumination device according to the present invention.
DESCRIPTION OF PREFERRED EMBODIMENTS
In the following de tailed description of the preferred embodiments, reference is made to the accompanying drawings that form a part hereof and in which are shown by way of illustration specific embodiments in which the invention may be practiced. It is understood that o the r embodiments may be utilized and structural changes may be made without departing from the scope of the present invention.
The present invention takes advantage of the efficiency of high-intensity, light-emitting diodes (LEDs) in the visible spectrum and/or infra-red (IR) or ultra-violet (UV), arranged in various patterns, the low-voltage properties of CMOS integrated circuits and components, and the efficiency derived from switching the current to and limiting the duration of current to the LEDs to project light efficiently and with constant brightness even as the battery supply voltage decays over time. The invention takes advantage of the dynamic impedance of the LEDs which causes the voltage across the LED to rise rapidly relative to the current flow through the LED to limit the initial current flow to the LED, when battery voltage is highest, to prevent wire bond heating from causing premature failure of the LEDs. The present invention controls the current flow duration (pulse width) to limit power dissipation in the LEDs during the LEDs' on state, and increasing the pulse width as the battery voltage decreases over time to maintain substantially constant perceived or average LED intensity over the course of the battery's life. The invention controls the switching frequency of the pulse width to further control the LED intensity and power dissipation while maintaining a constant light output from the LEDs as perceived or visible to the human eye, or a light-sensing device, e.g., camera, night-vision scope, CMOS and CCD sensor and pixel arrays. The present invention provides a compact, portable light source, preferably sized to be readily hand-held, for illuminating an object, several objects, or areas for human use and/or machine operation. In one embodiment, the invention measures battery voltage and in turn regulates the LED intensity. In another embodiment, the present invention uses a light-sensing device such as a light-sensing transistor or light-detecting diode (LDD) in proximity to the output LED(s) to measure the average brightness and further regulate the LEDs' output.
Another embodiment of the present invention provides operator-selectable control of the pulse frequency and/or the pulse width to provide a reduced apparent brightness in order to increase battery life in situations when maximum brightness is not required. In one such pulse-frequency embodiment, the apparent (visible) pulse frequency would provide a stroboscope effect for safety or entertainment. In this embodiment, the visibly interrupted or pulsed pulse train may include repetitive pulses or a coded sequence as in Morse code "SOS" or a predetermined password or security string of pulses that may then be used as a key or identifier. A further refinement of this embodiment would provide the user with a method for strobing out a message. It is understood that what appears to be a single visible pulse may actually include a high-frequency series of pulses in order to increase the apparent brightness of a single pulse while also protecting the LEDs from excessive power dissipation. In yet another pulse-frequency embodiment of the invention, a variable or adjustable constant sequence pulse train is established for the accurate measurement of the velocity or frequency of an object in motion or vibration.
Another embodiment of the present invention uses various colored LEDs for specialized purposes. In one such embodiment, long-wavelength LEDs, 660 nm or longer, are used to provide underwater divers or aquarium enthusiasts a light source for observing undersea life at night without adversely affecting the nocturnal activities of such wildlife. This functionality is also useful for tropical aquarium owners who also wish to observe the nocturnal activities of the occupants of their aquariums. In another such embodiment, short-wavelength blue LEDs are used with a UV filter to view fluorescing materials, including but not limited to: taggants, stamps, security codes and security seals. As UV LEDs become readily available (such as those announced as made by IBM Corporation in the Mar. 9, 1998 issue of Electronic Engineering Times, page 39), these could be used in place of the blue LEDs. In other embodiments, a suitable LED normally emitting in the blue spectrum, for example made from GaN (gallium nitride) or InGaN (indium gallium nitride), is pulsed by pulses of sufficiently high current to blue-shift the output and sufficiently short duration to not destroy the LED in order to maintain a constant light intensity while shifting the color spectrum from blue to ultraviolet. Other embodiments include IR LEDs for military or police use to enhance the usefulness of night-vision equipment and for friend-or-foe identification, multiple color LEDs to produce a white light source, and combinations of colored LEDs to enhance the ability of color-blind individuals to perceive colors. Other uses include LEDs chosen for use in photographic darkrooms wherein the LED wavelength is chosen to prevent undesired exposure of light-sensitive materials.
Another embodiment of the present invention uses LEDs of various "viewing" angles to achieve wide-angle viewing versus narrow-angle, long-range viewing and combinations thereof. A further refinement of this embodiment utilizes a Fresnel lens (or other lens or reflector arrangement) to provide a focusable light source. Another embodiment uses polarizers to reduce specular reflections for enhanced viewing or for use in machine-vision applications. Another embodiment utilizes quickly and easily pluggable/replaceable LED arrays or heads of various shapes, colors, and/or viewing angles for different applications.
In yet another embodiment, the light output is momentarily interrupted repetitively, or strobed, to indicate low battery condition with some estimation of time to battery failure, e.g., the number of pulses could indicate the estimated number of minutes of battery time. As the estimation of time to battery failure changes, the repetition rate is varied to indicate impending battery failure. It is understood that this operational mode is easily distinguished from other operational modes by the duration of on time versus off time. In strobe mode, low battery condition is indicated by dropping pulses; e.g., every fourth output pulse is dropped, or three of four pulses is dropped creating an easily distinguishable variance in visible output of the invention.
In another embodiment of the invention, a switch is utilized to control the functions (and/or brightness) of the invention. A variance of this embodiment uses a thumb-wheel, or rotary switch to vary the switching characteristics to produce a variable light output.
In another embodiment, a programmable microprocessor is utilized to provide control functionality.
FIG. 1 shows one embodiment of the present invention (a schematic representation of a LED flashlight 100) having a case 110, a battery 120 or other portable DC power supply, a power supply and control circuit 130, a switch circuit 140, a plurality of LEDs 150, and optionally a feedback circuit 160.
In various embodiments of the present invention, feedback circuit 160 (and similarly the other feedback circuits described herein) controls pulse width and/or frequency as a function of parameters such as battery voltage, LED light output intensity, power dissipation or device temperature, or LED color spectrum output.
Case 110 is any convenient size and shape, and is typically designed to hold the battery, provide a suitable grip to be handheld, and provide a housing for the circuitry and LEDs. In one embodiment, battery 120 includes one or more cells which can be any suitable technology such as alkaline dry cells or rechargeable cells. Alternatively, other portable DC electrical power sources can be used as desired in place of battery 120. Power supply and control circuit (PSCC) 130 responds to switch circuit to apply electrical power from battery 120 to LEDs 150, controlled in order to prevent overloading and premature destruction of LEDs 150 while minimizing power dissipation within PSCC 130, thus maximizing battery life, providing the desired accuracy or level of the amount of light emitted at different battery voltages or other environmental conditions that would otherwise vary the light output. Switch circuit 140 allows the user to control various flashlight functions such as, for example, on/off, setting light level, setting light color, setting pulse or strobe frequency, and checking battery voltage or remaining power. In one embodiment, PSCC 130 provides a pulse train, in which pulse frequency, pulse width, or pulse shape/height, and/or the number of LEDs that are driven, is controlled in order to provide a relatively constant light output level even as battery voltage declines and power is drained. In one embodiment, feedback 160 measures the light output of LEDs 150 (e.g., using a photo diode or other suitable light detecting device) and provides a signal that allows PSCC 130 to adjust the light output to a desired level (typically providing a constant light output even as battery voltage declines as power is drained). In one such embodiment, the width of each pulse is adjusted to keep a constant average light output (widening each pulse as the intensity of light decreases, in order to obtain a constant light output). In one such embodiment, flashlight 100 is used in conjunction with a portable video camcorder or other video camera, and feedback 160 measures the overall ambient light and provides a signal that allows generation of flashlight pulses to compensate for lack of light, in order to provide optimal lighting for the video camera. In one such embodiment, the pulses to the LEDs are synchronized to the video camera frame rate using optional pulse synchronization (sync) signal 170 in order that the light pulse from LEDs 150 is only on when the video camera shutter is collecting light (avoiding light output when the camera will not benefit from it). In another embodiment, feedback 160 measures battery voltage, and increases pulse width, frequency, or height as battery voltage or power declines. In yet another embodiment, feedback 160 measures the current going through LEDs 150, and makes the appropriate adjustment to pulse width or frequency in order to maintain constant or desired light output.
FIG. 2 is a schematic of one embodiment of a circuit used for flashlight 100. In this embodiment, normally open, momentary contact switch 146 is momentarily closed by a user to activate light output. Power-switch circuit 132 (in one embodiment, a TK 114 circuit by Toko America available from Digikey Corporation of Thief River Falls, Minn.) is turned on as its control input 131 is shorted to ground by switch 146, thus applying voltage to Vout, which is applied through resistor divider 138-138 to transistor 136. In other embodiments, circuit 132 is replaced by a simple slide switch as is used in conventional flashlights, and which, when closed, connects Vin to Vout (eliminating the need for resistors 137, 138, and 139, switch 146, and transistor 136). Transistor 136 and resistor 137 then maintain the control voltage low enough to keep power circuit 132 turned on even after switch 146 is released by the user to its open position (transistor 136 is "on" as long as circuit 132 is on and applying battery voltage to Vout). Thus power is applied to Vout until an OFF signal is set high on line 131 by microprocessor (MP) 134 (resistor 137 has a resistance that is set to a value that is small enough to keep the control pin of circuit 132 low unless overridden by the OFF signal from MP 134 going high). Microprocessor 134 is any suitable microprocessor, such as a PIC16C62X microcontroller by Microchip and available from Digikey Corp. of Thief River Falls, Minn., 56701. The PIC16C62X includes two analog comparators with a programmable on-chip voltage reference, a timer, and 13 input/output (I/O) pins each capable of direct LED driving of 25 mA source or sink. In one embodiment, MP 134 is programmed to receive a feedback signal 260 from feedback circuit 160, and on the basis of the feedback signal, adjust the drive signal(s) 250 to LEDs 150, thus adjusting the light output. In one such embodiment, a lookup table 234 is used to convert a digital value derived from feedback signal 260 into a digital value used to control drive signal 250. In one embodiment, optional feature switches 142 are provided to control various parameters of light output such as, for example, intensity, color, duration (i.e., time until automatic power down), frequency (i.e., a strobe control), etc. In one embodiment, an external pulse sync signal 170 is provided, isolated though a standard opto-isolator circuit 171, and provided as an input to pulse sync input pin 270) of MP 134. In one such embodiment, pulse sync signal 170 is driven from a video camera (such as a camcorder or a machine-vision video camera), in order to synchronize light output with the light gathering/shutter open times of the camera. In another such embodiment, pulse sync signal 170 is driven from a spark-plug-wire pickup in order to provide a timing strobe of light pulses for tuning an internal combustion engine.
In one embodiment, feature switches 142 include momentary contact switches in pairs, one switch of the pair used to increase a particular parameter, and the other switch of the pair used to decrease the particular parameter (such as is done commonly in television remote control devices). In one such embodiment, a pair of switches increases/decreases overall light output intensity. In another such embodiment, color is adjusted, e.g., using one pair of buttons for blue LED output, another pair for green LED output, and a third pair for red LED output; or using one pair to control the X-coordinate and another pair to control the Y-coordinate of chromaticity (such as a CIE chromaticity diagram's X and Y coordinates). In yet another such embodiment, a pair of switch buttons increases/decreases the remaining timeout value. In one embodiment, as a feature switch is pressed to increase or decrease a parameter, the number of LEDs that are "on" are varied to provide a visual indication to the user of the value of that parameter, for example the timeout value could be varied from one to ten minutes until power off, and as the button to increase that parameter is held down, the timeout parameter is increased successively from one to ten, and a corresponding number of LEDs (one to ten) are turned on to provide this visual indication. In other embodiments, audible indications of such parameters are provided, e.g., by providing variable pitch or numbers of clicks to give the user feedback as to the value of the parameters being adjusted or measured.
A primary feature of some embodiments of the present invention is to provide a large number of individual LEDs in order to provide sufficient generalized and/or focussed illumination to be useful as a handheld flashlight, or in particular, as an illumination source for a scene or object to be imaged by a video camera (e.g., in a camcorder or machine-vision system). With current low-cost, high intensity LEDs having a luminous intensity of, say 2 cd, twenty to fifty LEDs are typically needed to provide a good flashlight, although in some applications as few as seven LEDs provide desirable results. In one such embodiment, each individual LED is separately packaged in a transparent encapsulant (e.g., a T 13/4 package) that provides manufacturing efficiencies and provides better heat dissipation by spreading the active light emitting chips apart from one another. In some embodiments, white LEDs are used (such as white LEDs that utilize a blue LED chip and a YAG phosphor that converts a portion of the blue light to yellow, thus yielding a white-appearing light output, such as part number NSPW 310AS available from Nichia Chemical
Industries Ltd. of Japan and Nichia America Corp., 3775 Hempland Road, Mountville Pa., 17554). In other embodiments, standard high-efficiency colored LEDs of red, yellow, green, and/or blue are used to provide light of the desired intensity and color. In one such embodiment, LEDs of each color are controlled separately in order to provide the desired overall hue or whiteness of the combined light output. In one embodiment, surface-mount LEDs are used.
In an application such as providing illumination for a video camera, feedback circuit 160 measures the video output signal from the camera and provides a feedback signal 260 that allows adjustment of the light output pf LEDs 150 in order to optimize the video signal In one such embodiment, as shown in FIG. 5, the controlled LED light source is integrated into a handheld camcorder 500. In one such embodiment, the video camera circuit also provides pulse sync signal 170 in order to synchronize the light output to the video light gathering time windows. In another such embodiment, feedback circuit 160 measures the color balance of the video output signal, and provides separate feedback intensity control for each of a plurality of (e.g., two or three) separate groups of color LEDs, for example, red, green, and blue. In one embodiment, green LEDs such as part number NSPG 500S and blue LEDs such as part number NSPB 500S, both available from Nichia Chemical Industries Ltd. of Japan and Nichia America Corp., 3775 Hempland Road, Mountville Pa., 17554 are used, and red LEDs such as part number HLMP-C115 available from Hewlett Packard Company.
FIG. 3 a circuit block diagram of an LED flashlight circuit 300, which circuit is used in some embodiments of LED flashlight 100 of FIG. 1 or LED light source in video camera 500 of FIG. 5. Circuit 331 replaces circuit 132 and 134 of FIG. 2 using similar circuit concepts (however, in one embodiment, the entire circuitry of circuit 331 is integrated onto a single integrated circuit chip). When switch 146 is momentarily closed, circuit 331 draws output pin 332 low, turning on PNP transistor 133, which remains turned on until circuit 331 again detects that switch 146 is momentarily closed, at which time pin 332 is allowed to float high, turning off the flashlight circuit 300. One or more output pins 336 drive one or more low-threshold high-power MOSFETs 350 (e.g., a plurality of MOSFETs 350 are used to drive groups of LEDs of different colors, as described above). In some embodiments, pin 336 provides a variable pulse control signal to vary pulse width, pulse frequency, or both in order to control light output as described above. In the embodiment shown, output pin 333 is driven low to turn on LED 152, and in one such embodiment, pulses LED 152 in a manner that the pulses are perceptible to the human eye, and varying the pulse pattern or timing in order to indicate the estimated remaining battery power. For example, in one embodiment, from one to ten short, individually perceptible pulses closely spaced (e.g., one-third of a second apart) pulses are driven each time the flashlight is initially turned on, that is, ten pulses closely spaced indicate that 100% of the battery power remains, 9 pulses indicate that 90% of the battery power remains, . . . and 1 pulse indicates that 10% of the battery power remains. In another such embodiment, LED 152 is repeated pulsed in this manner, e.g., ten pulses spaced at 1/3 second, then a 3 second period of time when LED 152 is off, ten pulses spaced at 1/3 second, then a 3 second period of time when LED 152 is off, in a repeating pattern as long as the flashlight is on. In one such embodiment, this provides the user with the only indication of remaining battery life, since LEDs 151 are driven to provide constant illumination, regardless of battery voltage variations or other factors that would otherwise vary light output. In other embodiments, feedback circuit 160 is omitted, and such factors do affect light output. Feedback circuit 160 is as described above, and measures light emitted by the LEDs, battery voltage, LED current, and/or other parameters in order to provide circuit 331 with information to be used to control output pin 336, and thus light output. In one embodiment that measures light output in feedback circuit 160, the width of the pulse needed to obtain a certain level of light output provides indirect information regarding remaining battery power, and is measured and converted into the visual indication of remaining power to be displayed by LED 152. In another embodiment, the amount of remaining battery power is visually indicated by turning on a proportional number of the LEDs 151 as power is initially applied, so the user, by seeing how many LEDs are lit during this initial power-indication mode, can determine the remaining battery power. Thus, by varying the number of perceptible flashes or the number of lit LEDs, or other visual indication, the remaining battery power can be conveyed to the user.
FIG. 4 a circuit block diagram of an LED flashlight circuit 400, which circuit is used in some embodiments of LED flashlight 100 of FIG. 1 or LED light source in video camera 500 of FIG. 5. In this circuit 400, switch 147 applies (and removes) power to the circuit 400. In this embodiment, circuit 433 provides a continuous series of very short pulses (e.g., 10 microseconds wide each) at a frequency much higher than the flicker rate of the human eye (e.g., between 100 Hz to 50 KHz) that drive the trigger input of circuit 434 (in this embodiment, circuits 433 and 434 are each 555-type timer circuits, or each are one-half of a 556 dual timer). Resistor 431 and constant voltage circuit 432 provide a fixed voltage to control pin 5 of circuit 555. Since circuit 434 will operate over a wide range of voltage, as the voltage of Vout decreases, the constant voltage at pin 5 (from circuit 432) will be relatively higher, thus increasing the pulse width generated by circuit 434 and output on its pin 3. As in FIG. 3, MOSFET 350 shorts the anodes of LEDs 151 to ground for the duration that pulse from circuit 434 is high. This can provide 100 milliamps or more through each LED 151 when the battery is fully charged, but only for a very short pulse. While the 100 mA, if constant, would overload the ILEDs, the short pulses are tolerated. As the battery power is drained, the voltage of Vout decreases, and the pulse width increases. In this way, pulse width increases as battery voltage decreases, thus compensating at least partially for the reduced peak intensity of the LEDs at lower voltage. On the other hand, LED 452 is driven directly from output pin 3 of circuit 434 though current limiting resistor 153. LEDs 151 are "on" for proportionally longer as the pulse width increases, however, LED 452 is on proportionally shorter as pulse width increases, thus LED 452 becomes dimmer as voltage decreases, providing a visual indication of remaining battery power.
FIG. 5 is a diagram showing a controlled LED light source is integrated into a handheld camcorder 500. In this embodiment, camcorder 500 includes lens 520, case 510, video circuit 570, recorder apparatus 580, battery 120, control circuit 130, feedback circuit 160, and LEDs 150. Typically, lens 520 forms an image of object 599 onto a CCD imaging array that is part of video circuit 570 (i.e., lens 520 and video circuit 570 form a video camera), and the corresponding video signal is recorded onto media (such as video tape or recordable digital video disk (DVD)) in recorder 580. In other applications such as machine vision, the video signal is coupled to an image processor that in turn controls some manufacturing process, for example, and part inspection or robot arm control is accomplished. In one embodiment, feedback circuit 160 takes input from the video signal only in order to control the amount of light emitted from LEDs 150. In other embodiments, feedback circuit 160, instead of or in addition to input from the video signal, takes feedback input 165 from a photosensor in order to control LED light output.
FIG. 6 is a graph of color spectrum versus current for an LED to be used in one embodiment of the present invention. As is seen in the graph, as the LED current increases from 10 mA to 35 mA, the color spectrum of this exemplary LED shifts from centered at approximately 440 nanometers (blue) to centered at approximately at 380 nanometers (ultraviolet), and the overall intensity increases with increasing current. Such an LED is described by M Schauler et al, GaN based LED's with different recombination zones, MSR Internet Journal of Nitride Research, Volume 2 Article 44, Oct. 8, 1997 (internet address http://nsr.mij.mrs.org/2/44/complete.html). In one such embodiment, the above described pulse-width control or frequency control circuits (such as feedback circuit 160 and control circuit 134) are used to maintain a desired illumination intensity as the color spectrum is changed by changing the current through the LED. In one such embodiment, color balance as measured by feedback circuit 160 is used to change the current of each pulse and thus the color spectrum in order to control or maintain color balance.
By controlling the amount of current (the height of each pulse), the color spectrum of the output light can be adjusted (i.e., for the above described LED, the color spectrum center wavelength is adjustable from 440 nm blue to 380 nm ultraviolet), and by simultaneously controlling pulse width and/or pulse frequency, the intensity can also be controlled (i.e., one can vary the intensity, or even keep a constant intensity as the pulse height is adjusted to change color output), e.g., by varying pulse width to provide a constant perceived or average intensity even as the color changes. FIG. 7 shows one circuit 700 to accomplish such control. The user controls the color desired via switches 140 coupled to control circuit 730. Circuit 730 then controls the current of transistor 755 by well-known techniques such as a current mirror, and the pulse width or frequency to transistor 750 as described above (in one embodiment, a lookup table is used to choose a predetermined pulse width based on the user-selected or set color, and the current is determined by another corresponding lookup table is used to choose an appropriate current).
FIG. 8 shows another circuit 800 to accomplish such control. Feedback circuit 840 is adjusted to controls the color desired based on a detected color signal from color detector 841 in control circuit 830. Control circuit 830 then controls the current of transistor 755 by a current mirror with transistor 754. In addition, the pulse width or frequency to gated register 842 is optionally controlled by one or more feedback circuits 860 (which is controlled by a signal indicating supply voltage, tile temperature of LEDs 151, measured light output intensity or any other parameter over which control is desired) as described above (in one embodiment, a lookup table is used to choose a predetermined pulse width based on the user-selected or set color, and the current is determined by another corresponding lookup table is used to choose an appropriate current). In one embodiment, gated register 842 receives and stores a binary number value from feedback circuit 840, and receives a variable-frequency and/or variable-width output-enable pulse 835 from pulse-width modulator (PWM) circuit 834. PWM circuit 834 is driven by frequency generator 833. In one embodiment, both PWM circuit 834 and frequency generator 833 are set to provide fixed frequency and fixed width pulses (i.e., no feedback used). In other embodiments, one or both of frequency and pulse width are variable, and in some embodiments, the variability is controlled by feedback, and in other embodiments these parameters are set-able to values chosen by a user. In some embodiments, a maximum frequency for a given pulse width, or a maximum pulse width for a given frequency is predetermined in order to prevent destruction of LEDs 151 from excessive power. In other embodiments, a temperature feedback signal indicating the temperature of LEDs 151 is coupled to feedback circuit 860 to prevent overheating of LEDs 151. In some embodiments, Feedback circuit 860 simply inhibits and/or shortens pulses based on temperature feedback or on a predetermined maximum rate limit or pulse-width limit. FET transistors 851, 852, 853, and 854, and their respective resistors R, 2R, 4R, and 8R, along with trimming resistor 859 form a controllable variable current source, which is multiplied by approximately the factor .beta./(.beta.+2) by the current mirror of transistors 754 and 755 to get the sum of the current though LEDs 151. For optimal results, transistors 754 and 755 are formed as s single integrated three-terminal device on a single substrate, in order to achieve matched betas and temperature dependence. In one such embodiment, transistor 755 is formed of multiple individual transistors wired in parallel in order to achieve higher output current (at the collector of transistor 755) for a given input current (at the collector of transistor 754 and the bases of the two transistors). In the embodiment shown, this current mirror allows circuit 830 to determine the current through transistor 755 substantially independent of the voltage of Vcc and the voltage-current relationships of LEDs 151. In the embodiment shown, LEDs 151 are wired in parallel, however, in other embodiments a single LED device is used, or a plurality of LEDs 151 are instead wired in series, or in a series-parallel arrangement as is shown in FIG. 10.
FIG. 9 is a graph of color spectrum (photoluminescence) versus temperature for an LED to be used in one embodiment of the present invention. Such an LED is described by B. Monemar et al, Free Excitons in GaN, MSR Internet Journal of Nitride Research, Volume 1 Article 2, Jul. 8, 1996 (internet address http://nsr.mij.mrs.org/1/2/complete.html). In one embodiment of the present invention, a GaN or InGaN LED that exhibits a temperature-dependent color spectrum light output (i.e., electroluminescence, or light output due to a current flowing through the LED which also exhibits color-temperature dependence, as opposed to the photoluminescence graphed in FIG. 9) has its color spectrum controlled by one of the circuits described for FIGS. 1, 2, 3, 4, 5, 7, or 8. In one such embodiment, feedback reduces or eliminates color changes that would otherwise occur as temperature of the LED changed. In another such embodiment, color changes are purposely induced by changing the temperature of the LED, either by heating or cooling the LED with an external temperature-change device such as a resistor, or by inducing internal temperature changes by changing the average driving current to effect a change in junction temperature in the LED. In some such embodiments, a color detector such as are well known in the art is used to provide a signal to provide feedback to control temperature.
FIG. 10 is a block diagram of the control circuit 130 for one embodiment of illumination system 100. An Oscillator 15 (in the embodiment shown, oscillator 15 is part of an image processor as shown which is coupled to an electronic camera 14, e.g., a charge-coupled device (CCD)), controlled by pulse-frequency circuit (such as circuit 833 of FIG. 8 or frequency generator 433 of FIG. 4), sends a trigger signal to power supply 20. In one embodiment, the image processor 15 generates one pulse or a plurality of pulses for each CCD frame, wherein the number of pulses generated is sufficient to provide a desired accumulation of light received by camera 14 for each frame. Within power supply 20, the trigger signal activates pulse generator 201 to generate a control pulse of a length determined by pulse-length circuit (such as PWM circuit 834 of FIG. 8 or PWM 434 of FIG. 4) The control pulse is used to turn on transistor Q1 to generate a flash on LEDs 25, which is current-limited by resistor R3. The control pulse also activates the maximum-rate-limit circuit 202, which inhibits any further control pulses from pulse generator 201 for a predetermined amount of time. The 12 volt signal from power supply 20 is filtered by the low-pass filter comprising C1, L1, D1, and R1, and charges capacitors C2 through C.sub.N (in one embodiment, N is 12). In one such embodiment, C1 through C12 are each 2200 .mu.F, L1 is 40 .mu.H iron-core, D1 as a 1N4001 diode, and R1 is a 0 ohm conductor. C2 through C.sub.N are discharged through fifteen series-wired LEDs 25, which in this embodiment are wired in a parallel-series manner as shown, and R3 and Q1, as activated by the above-described control pulse. In one such embodiment, R3 is replaced by a zero-ohm conductor, and the voltage drop across the LEDs and Q1 is used to self-limit the current through the LEDs. The control pulse is fed across resistor R2, which in one embodiment is 100 K.OMEGA., to develop the necessary voltage for driving transistor Q1, which in this embodiment is a MTP75N05HD MOSFET.
FIG. 11 is a more-detailed schematic diagram of power supply 20. The input trigger is fed through resistor R2 to drive the input of opto-isolator OI1. The output of opto-isolator OI1 is coupled through capacitor C12 (and the associated circuit R4, R6 and D2) to the TRG input of timer circuit 1C1.sub.A. (In one embodiment, timers 1C1.sub.A and 1C1.sub.B are each 1/2 of a 556-type dual timer.) The timing constant of timer 1C1.sub.A is set by C14 and R1-x, (where x is selected from 1 through N), and determines
the pulse width of the control pulse driving Q1, and thus the LEDs. In one embodiment, five selectable pulse widths are predetermined and selected by SW1, which is a five-way exclusive dual-pole-single-throw switch, wherein one resistor of the set R1-1 through R1-N is selected for connection to the DIS input pin of 1C1.sub.A, and a corresponding one resistor of the set R2-1 through R2-N is selected for connection to the DIS input pin of 1C1.sub.B. The timing constant of timer 1C1.sub.B is set by C17 and R2-x, (where x is selected from 1 through N), and determines the minimum time between control pulses driving Q1, and thus the LEDs. In one embodiment, the five selectable predetermined pulse widths are 25 microseconds (.mu.s), 50 .mu.s, 100 .mu.s, 200 .mu.s and 500 .mu.s; the corresponding maximum pulse rates controlled by maximum rate limit circuit 202 are 200 Hz, 120 Hz, 60 Hz, 30 Hz, and 10 Hz, respectively, and are predetermined and selected by SW1. Thus, in the embodiment which uses a 60 Hz camera image rate, 100 .mu.s-long control pulses are used to activate LEDs 25. In one embodiment, it is desired to have an average LED illumination intensity of at least ten times the ambient light; thus, when imaging device 14 is taking one frame every 16.7 milliseconds, a 100 microsecond pulse should be at least 1670 times as intense as the ambient light. In one such an embodiment, a shroud is used to reduce the ambient light, and a red filter (substantially transparent to the peak wavelength of illumination source 18) is placed over the lens of imaging device 14 in order to reduce ambient light and pass the light of illumination source 18. The control pulse output signal is driven through resistor R3.
In one embodiment, opto-isolator OI1 is a 4N37-type part, resistor R2 is 100.OMEGA. resistor R3 is 100.OMEGA., resistor R7 is 1 M.OMEGA., resistor R8 is 1 K.OMEGA. and visible-color LED D3 indicates when the circuit is active, resistor R4 is 4700.OMEGA., resistor R5 is 10.OMEGA., resistor R6 is 10 K.OMEGA., diode D2 is a 1N914, resistor R1-1 is 2.26 K.OMEGA., resistor R1-2 is 4.53 K.OMEGA., resistor R1-3 is 9.1 K.OMEGA., resistor R1-4 is 18.2 K.OMEGA., resistor R1-5 is 45.3 K.OMEGA., resistor R2-1 is 37.4 K.OMEGA., resistor R2-2 is 75 K.OMEGA., resistor R2-3 is 150 K.OMEGA., resistor R2-4 is 301 K.OMEGA., resistor R2-5 is 909 K.OMEGA., C14 is 0.01 .mu.F, C17 is 0.1 .mu.F, C12 is 0.001 .mu.F, C10 is 100 .mu.F, C11 is 0.1 .mu.F, C13, C15, and C16 are each 0.01 .mu.F, Q2 and Q3 are each 2N3904 NPN transistors, and RP1 is a 10 K.OMEGA. resistor pack.
In one embodiment such as shown in FIG. 5 of FIG. 10, the image detector (i.e., video imager circuit 590 or CCD Camera 14, respectively) is shuttered (in one embodiment, electronic shuttering of a CCD array is performed) in order to shorten the time period used to accumulate light for each frame image. In one such embodiment, the camera shutter is "open" for a period of only about 30 microseconds (in other embodiments, for shorter periods such as 10 microseconds or 1 microsecond), and the LED illumination source 150 is activated synchronously, in order to minimize the amount of ambient light received, and to maximize the amount of light received from LED source 150. In one such embodiment, this allows improved detection of objects of interest such as objects that reflect, absorb, or fluoresce from the wavelength(s) of light from LED illumination source 150 differently than do surrounding objects, but that are difficult to distinguish in ambient light. Examples are taggents having colors that show up best when illuminated with certain wavelengths, e.g., fluorescing materials. Further, such embodiments reduce the problem of achieving a high ratio of LED light to ambient light.
In the present invention, a longer battery life (or more efficient use of a wall-powered DC source) is achieved because (1) the LED light output is synchronized with the camera shutter (or other light receiver) thus reducing the amount of wasted light. In some embodiments, the LEDs are operated an an operating point that provides the most light output per unit of power input, using pulse width or frequency to adjust the total light output to a desired level.
In one embodiment of FIG. 5, the plurality of LED colors are sequentially and separately pulsed (e.g., a red pulse, then a green pulse, then a blue pulse), and a single wide-spectrum feedback detector and circuit is used to separately adjust each of the colors of output LED light. This provides the ability to color balance with a lower cost than having a color detector that needs to differentiate three colors from a single light pulse having all colors. In one embodiment, a color spectrum of a single LED or set of LEDs is adjusted (e.g., by varying the LED current and pulse width) in order to tune the color to better detect certain objects (e.g., the timing mark on a grimy gas engine, or objects in a fog).
In one embodiment, surface-mount LEDs are used.
It is to be understood that the above description is intended to be illustrative, and not restrictive. Many other embodiments will be apparent to those of skill in the art upon reviewing the above description. The scope of the invention should, therefore, be determined with reference to the appended claims, along with the full scope of equivalents to which such claims are entitled.
* * * * *